Learn R Programming

gageRR (version 0.1.0)

anova_var_calcs: ANOVA Variance Component Calculations

Description

ANOVA Variance Component Calculations

Usage

anova_var_calcs(data, part, operator, meas)

Value

A list of numeric values for repeatability, reproducibility, total GRR, part-to-part, and total variance components.

Arguments

data

An R dataframe or tibble.

part

A column in data specifying the unique ID of the part being measured

operator

A column in data specifying the operator for the recorded measurement

meas

A column in data where the measurement value is recorded.

Examples

Run this code
data = data.frame(
SN = c(
'SerialNumber_01',
'SerialNumber_01',
'SerialNumber_02',
'SerialNumber_02',
'SerialNumber_01',
'SerialNumber_01',
'SerialNumber_02',
'SerialNumber_02'),

Operator = c(
'Operator_01',
'Operator_01',
'Operator_01',
'Operator_01',
'Operator_02',
'Operator_02',
'Operator_02',
'Operator_02'),

Measure = c(
0.0172,
0.0177,
0.0155,
0.0159,
0.0174,
0.0181,
0.0152,
0.0176))

anova_var_calcs(data, part = 'SN', operator = 'Operator', meas = 'Measure')

Run the code above in your browser using DataLab