Learn R Programming

gageRR (version 0.1.0)

grr_calc: Gage R&R Evaluation

Description

Gage R&R Evaluation

Usage

grr_calc(data, part, operator, meas, LSL = NULL, USL = NULL, method = "anova")

Value

A list containing:

  • VarianceComponents: Data frame of variance components and percent contribution

  • GageEval: Data frame of study variation metrics

  • AnovaTable: ANOVA table (if method = "anova")

Arguments

data

An R dataframe or tibble containing the required identifier and measurement columns.

part

A string giving the column name specifying the unique ID of the part being measured. The column should be a character or factor.

operator

A string giving the column name specifying the operator for the recorded measurement. The column should be a character or factor.

meas

A string giving the column name where the measurement value is recorded. The column must be numeric and contain no missing or infinite values.

LSL

A number specifying the lower specification limit.

USL

A number specifying the upper specification limit.

method

A string specifying "anova" or "xbar_r".

Examples

Run this code
data <- data.frame(
  SN = rep(c("SerialNumber_01","SerialNumber_02"), each = 4),
  Operator = rep(c("Operator_01","Operator_02"), each = 2, times = 2),
  Measure = c(0.0172,0.0177,0.0155,0.0159,0.0174,0.0181,0.0152,0.0176)
)

grr_calc(data, part = "SN", operator = "Operator",
         meas = "Measure", LSL = 0, USL = 0.040, method = "xbar_r")

Run the code above in your browser using DataLab