Learn R Programming

gageRR (version 0.1.0)

ss_calcs: ANOVA Sum of Squares Calculations

Description

ANOVA Sum of Squares Calculations

Usage

ss_calcs(data, part, operator, meas)

Value

A list of numeric values for the sum of squares error for operator, part, equipment, operator and part interaction, and total error.

Arguments

data

An R dataframe or tibble containing the required identifier and measurement columns.

part

A column in data specifying the unique ID of the part being measured. The column should be a character or factor vector.

operator

A column in data specifying the operator for the recorded measurement. The column should be a character or factor vector.

meas

A column in data where the measurement value is recorded. The column must be numeric and contain no missing or infinite values.

Examples

Run this code
data = data.frame(
SN = c(
'SerialNumber_01',
'SerialNumber_01',
'SerialNumber_02',
'SerialNumber_02',
'SerialNumber_01',
'SerialNumber_01',
'SerialNumber_02',
'SerialNumber_02'),

Operator = c(
'Operator_01',
'Operator_01',
'Operator_01',
'Operator_01',
'Operator_02',
'Operator_02',
'Operator_02',
'Operator_02'),

Measure = c(
0.0172,
0.0177,
0.0155,
0.0159,
0.0174,
0.0181,
0.0152,
0.0176))

ss_calcs(data, part = 'SN', operator = 'Operator', meas = 'Measure')

Run the code above in your browser using DataLab